@@ -18,7 +18,6 @@
 #include <kurldrag.h>
 #include <twin.h>
 #include <tqcstring.h>
-#include <tqdesktopwidget.h>
 #include <tqevent.h>      //::stateChanged()
 #include <tqlayout.h>     //ctor
 #include <tqpopupmenu.h>  //because XMLGUI is poorly designed
@@ -48,6 +47,9 @@ extern "C"
 }
 #endif
 
+constexpr auto kAspectSelectActionName = "aspect_ratio_select";
+constexpr auto kAudioSelectActionName = "audio_channels_select";
+constexpr auto kSubtitleSelectActionName = "subtitle_channels_select";
 
 namespace Codeine {
 
@@ -116,26 +118,27 @@ MainWindow::MainWindow()
    }
 
    {
-      TQPopupMenu *menu = 0, *settings = static_cast<TQPopupMenu*>(factory()->container( "settings", this ));
-      int id = SubtitleChannelsMenuItemId, index = 0;
-
-      #define make_menu( name, text ) \
-            menu = new TQPopupMenu( this, name ); \
-            menu->setCheckable( true ); \
-            connect( menu, TQ_SIGNAL(activated( int )), engine(), TQ_SLOT(setStreamParameter( int )) ); \
-            connect( menu, TQ_SIGNAL(aboutToShow()), TQ_SLOT(aboutToShowMenu()) ); \
-            settings->insertItem( text, menu, id, index ); \
-            settings->setItemEnabled( id, false ); \
-            id++, index++;
-
-      make_menu( "subtitle_channels_menu", i18n( "&Subtitles" ) );
-      make_menu( "audio_channels_menu", i18n( "A&udio Channels" ) );
-      make_menu( "aspect_ratio_menu", i18n( "Aspect &Ratio" ) );
-      #undef make_menu
-
-      Codeine::insertAspectRatioMenuItems( menu ); //so we don't have to include xine.h here
-
-      settings->insertSeparator( index );
+      /* Disable aspect/channel menus until the stream has loaded;
+       * Make sure they have the same default item selected. */
+      TQStringList defaultItems("&Determine Automatically");
+      if (const auto aspectAction = dynamic_cast<TDESelectAction *>(action(kAspectSelectActionName)))
+      {
+         aspectAction->setToolTip(i18n("Aspect Ratio"));
+         insertAspectRatioMenuItems(aspectAction);
+         aspectAction->setEnabled(false);
+      }
+      if (const auto audioChannelAction = dynamic_cast<TDESelectAction *>(action(kAudioSelectActionName)))
+      {
+         audioChannelAction->setToolTip(i18n("Audio Channels"));
+         audioChannelAction->setItems(defaultItems);
+         audioChannelAction->setEnabled(false);
+      }
+      if (const auto subChannelAction = dynamic_cast<TDESelectAction *>(action(kSubtitleSelectActionName)))
+      {
+         subChannelAction->setToolTip(i18n("Subtitles"));
+         subChannelAction->setItems(defaultItems);
+         subChannelAction->setEnabled(false);
+      }
    }
 
    TQObjectList *list = toolBar()->queryList( "TDEToolBarButton" );
@@ -170,10 +173,14 @@ MainWindow::init()
 
    connect( engine(), TQ_SIGNAL(statusMessage( const TQString& )), this, TQ_SLOT(engineMessage( const TQString& )) );
    connect( engine(), TQ_SIGNAL(stateChanged( Engine::State )), this, TQ_SLOT(engineStateChanged( Engine::State )) );
-   connect( engine(), TQ_SIGNAL(channelsChanged( const TQStringList& )), this, TQ_SLOT(setChannels( const TQStringList& )) );
    connect( engine(), TQ_SIGNAL(titleChanged( const TQString& )), m_titleLabel, TQ_SLOT(setText( const TQString& )) );
    connect( m_positionSlider, TQ_SIGNAL(valueChanged( int )), this, TQ_SLOT(showTime( int )) );
 
+   connect(engine(), TQ_SIGNAL(audioChannelsChanged(const TQStringList &)),
+      this, TQ_SLOT(setAudioChannels(const TQStringList &)));
+   connect(engine(), TQ_SIGNAL(subtitleChannelsChanged(const TQStringList &)),
+      this, TQ_SLOT(setSubtitleChannels(const TQStringList &)));
+
    if( !engine()->init() ) {
       KMessageBox::error( this, i18n(
          "<qt>xine could not be successfully initialised. " PRETTY_NAME " will now exit. "
@@ -257,13 +264,22 @@ MainWindow::setupActions()
 
    new TDEAction( i18n("Reset Video Scale"), "viewmag1", Key_Equal, videoWindow(), TQ_SLOT(resetZoom()), ac, "reset_zoom" );
    new TDEAction( i18n("Media Information"), "messagebox_info", Key_I, this, TQ_SLOT(streamInformation()), ac, "information" );
-   new TDEAction( i18n("Menu Toggle"), "media-optical-dvd-unmounted", Key_R, engine(), TQ_SLOT(toggleDVDMenu()), ac, "media-optical-dvd-unmounted" );
+   new TDEAction( i18n("Menu Toggle"), "media-optical-dvd-unmounted", Key_R, engine(), TQ_SLOT(toggleDVDMenu()), ac, "toggle_dvd_menu" );
    new TDEAction( i18n("&Capture Frame"), "frame_image", Key_C, this, TQ_SLOT(captureFrame()), ac, "capture_frame" );
 
    new TDEAction( i18n("Video Settings..."), "configure", Key_V, this, TQ_SLOT(configure()), ac, "video_settings" );
    new TDEAction( i18n("Configure xine..."), "configure", 0, this, TQ_SLOT(configure()), ac, "xine_settings" );
 
-   (new KWidgetAction( m_positionSlider, i18n("Position Slider"), 0, 0, 0, ac, "position_slider" ))->setAutoSized( true );
+   (new KWidgetAction( m_positionSlider, i18n("Position Slider"), nullptr, nullptr, nullptr, ac, "position_slider" ))->setAutoSized( true );
+
+   const auto audioSelectAction = new TDESelectAction(i18n("A&udio Channels"), 0, ac, kAudioSelectActionName);
+   connect(audioSelectAction, TQ_SIGNAL(activated(int)), engine(), TQ_SLOT(setStreamParameter(int)));
+
+   const auto subSelectAction = new TDESelectAction(i18n("&Subtitles"), 0, ac, kSubtitleSelectActionName);
+   connect(subSelectAction, TQ_SIGNAL(activated(int)), engine(), TQ_SLOT(setStreamParameter(int)));
+
+   const auto aspectSelectAction = new TDESelectAction(i18n("Aspect &Ratio"), 0, ac, kAspectSelectActionName);
+   connect(aspectSelectAction, TQ_SIGNAL(activated(int)), engine(), TQ_SLOT(setStreamParameter(int)));
 
    m_volumeAction = new VolumeAction( toolBar(), ac );
 }
@@ -381,7 +397,7 @@ MainWindow::load( const KURL &url )
    if (url.protocol() == "media") {
       #define UDS_LOCAL_PATH (72 | TDEIO::UDS_STRING)
       TDEIO::UDSEntry e;
-      if (!TDEIO::NetAccess::stat( url, e, 0 ))
+      if (!TDEIO::NetAccess::stat( url, e, nullptr ))
          MessageBox::sorry( "There was an internal error with the media slave..." );
       else {
          TDEIO::UDSEntry::ConstIterator end = e.end();
@@ -571,7 +587,7 @@ MainWindow::fullScreenToggled( bool isFullScreen )
       delete s_handler;
 
    // prevent videoWindow() moving around when mouse moves
-   setCentralWidget( isFullScreen ? 0 : videoWindow() );
+   setCentralWidget( isFullScreen ? nullptr : videoWindow() );
 }
 
 void
@@ -593,54 +609,49 @@ MainWindow::streamInformation()
 }
 
 void
-MainWindow::setChannels( const TQStringList &channels )
+MainWindow::setAudioChannels(const TQStringList &channels) const
 {
    DEBUG_FUNC_INFO
 
-   //TODO -1 = auto
+   /* Xine uses -1 and -2 to indicate that a channel should be determined automatically or
+    * turned off.  TDESelectAction inserts items starting from index 0, so we add 2 to the
+    * channel returned from TheStream to match. */
 
-   TQStringList::ConstIterator it = channels.begin();
-
-   TQPopupMenu *menu = (TQPopupMenu*)child( (*it).latin1() );
-   menu->clear();
-
-   menu->insertItem( i18n("&Determine Automatically"), 1 );
-   menu->insertSeparator();
-
-   //the id is crucial, since the slot this menu is connected to requires
-   //that information to set the correct channel
-   //NOTE we subtract 2 in xineEngine because TQMenuData doesn't allow negative id
-   int id = 2;
-   ++it;
-   for( TQStringList::ConstIterator const end = channels.end(); it != end; ++it, ++id )
-      menu->insertItem( *it, id );
-
-   menu->insertSeparator();
-   menu->insertItem( i18n("&Off"), 0 );
-
-   id = channels.first() == "subtitle_channels_menu" ? SubtitleChannelsMenuItemId : AudioChannelsMenuItemId;
-   MainWindow::menu( "settings" )->setItemEnabled( id, channels.count() > 1 );
+   if (const auto audioSelection = dynamic_cast<TDESelectAction *>(action(kAudioSelectActionName)))
+   {
+      TQStringList audioChannels(channels);
+      audioChannels.prepend("&Determine Automatically");
+      audioChannels.prepend("&Off");
+      audioSelection->setItems(audioChannels);
+      audioSelection->popupMenu()->insertSeparator(2);
+      audioSelection->setCurrentItem(TheStream::audioChannel() + 2);
+      audioSelection->setEnabled(channels.count());
+   }
+   else
+   {
+      Debug::error() << "Failed to update the audio channels (selection menu not found)" << endl;
+   }
 }
 
 void
-MainWindow::aboutToShowMenu()
+MainWindow::setSubtitleChannels(const TQStringList &channels) const
 {
-   TQPopupMenu *menu = (TQPopupMenu*)sender();
-   TQCString name( sender() ? sender()->name() : 0 );
+   DEBUG_FUNC_INFO
 
-   // uncheck all items first
-   for( uint x = 0; x < menu->count(); ++x )
-      menu->setItemChecked( menu->idAt( x ), false );
-
-   int id;
-   if( name == "subtitle_channels_menu" )
-      id = TheStream::subtitleChannel() + 2;
-   else if( name == "audio_channels_menu" )
-      id = TheStream::audioChannel() + 2;
+   if (const auto subSelection = dynamic_cast<TDESelectAction *>(action(kSubtitleSelectActionName)))
+   {
+      TQStringList subChannels(channels);
+      subChannels.prepend("&Determine Automatically");
+      subChannels.prepend("&Off");
+      subSelection->setItems(subChannels);
+      subSelection->popupMenu()->insertSeparator(2);
+      subSelection->setCurrentItem(TheStream::subtitleChannel() + 2);
+      subSelection->setEnabled(channels.count());
+   }
    else
-      id = TheStream::aspectRatio();
-
-   menu->setItemChecked( id, true );
+   {
+      Debug::error() << "Failed to update the subtitle channels (selection menu not found)" << endl;
+   }
 }
 
 void
@@ -681,10 +692,10 @@ MainWindow::keyPressEvent( TQKeyEvent *e )
 }
 
 TQPopupMenu*
-MainWindow::menu( const char *name )
+MainWindow::menu( const TQString& name )
 {
    // KXMLGUI is "really good".
-   return static_cast<TQPopupMenu*>(factory()->container( name, this ));
+   return dynamic_cast<TQPopupMenu*>(factory()->container( name, this ));
 }
 
 
@@ -701,17 +712,23 @@ action( const char *name )
 {
    #define QT_FATAL_ASSERT
 
-   MainWindow *mainWindow = 0;
-   TDEActionCollection *actionCollection = 0;
-   TDEAction *action = 0;
+   MainWindow *mainWindow = nullptr;
+   TDEActionCollection *actionCollection = nullptr;
+   TDEAction *action = nullptr;
 
-   if( mainWindow = (MainWindow*)kapp->mainWidget() )
-      if( actionCollection = mainWindow->actionCollection() )
-         action = actionCollection->action( name );
+   mainWindow = dynamic_cast<MainWindow *>(kapp->mainWidget());
+   if (mainWindow)
+   {
+      actionCollection = mainWindow->actionCollection();
+      if (actionCollection)
+      {
+         action = actionCollection->action(name);
+      }
+   }
 
-   Q_ASSERT( mainWindow );
-   Q_ASSERT( actionCollection );
-   Q_ASSERT( action );
+   Q_ASSERT(mainWindow);
+   Q_ASSERT(actionCollection);
+   Q_ASSERT(action);
 
    return action;
 }
