@@ -40,9 +40,9 @@ namespace Codeine
       void engineStateChanged( Engine::State );
       void init();
       void showTime( int = -1 );
-      void setChannels( const TQStringList& );
-      void aboutToShowMenu();
       void fullScreenToggled( bool );
+      void setAudioChannels(const TQStringList&) const;
+      void setSubtitleChannels(const TQStringList&) const;
 
    private:
       void setupActions();
@@ -50,7 +50,7 @@ namespace Codeine
       bool load( const KURL& );
       bool open( const KURL& );
 
-      TQPopupMenu *menu( const char *name );
+      TQPopupMenu *menu(const TQString&);
 
       virtual void timerEvent( TQTimerEvent* );
       virtual void dragEnterEvent( TQDragEnterEvent* );
