@@ -90,11 +90,14 @@ MainWindow::engineStateChanged( Engine::State state )
       file_menu->changeItem( play_id, item.iconSet(), item.text() );
       file_menu->setItemChecked( play_id, false );
 
-      settings_menu->setItemEnabled( AspectRatioMenuItemId, state & (Playing | Paused) && TheStream::hasVideo() );
-
-      // set correct aspect ratio
-      if( state == Loaded )
-         static_cast<TQPopupMenu*>(child( "aspect_ratio_menu" ))->setItemChecked( TheStream::aspectRatio(), true );
+      if (const auto aspectAction = dynamic_cast<TDESelectAction *>(action("aspect_ratio_select")))
+      {
+         aspectAction->setEnabled((state & (Playing | Paused)) && TheStream::hasVideo());
+         if (state == Loaded)
+         {
+            aspectAction->setCurrentItem(TheStream::aspectRatio());
+         }
+      }
    }
 
 
@@ -120,6 +123,8 @@ MainWindow::engineStateChanged( Engine::State state )
       case Engine::Paused:
          m_positionSlider->setEnabled( TheStream::canSeek() );
          break;
+      default:
+         break;
    }
 
 
@@ -160,6 +165,8 @@ MainWindow::engineStateChanged( Engine::State state )
       case Engine::TrackEnded:
          m_titleLabel->setText( TheStream::prettyTitle() );
          break;
+      default:
+         break;
    }
 
 
@@ -187,6 +194,8 @@ MainWindow::engineStateChanged( Engine::State state )
       case Engine::Playing:
          toolBar()->hide();
          break;
+      default:
+         break;
       }
    }
 }
