@@ -48,8 +48,8 @@ public:
 
 
 VolumeAction::VolumeAction( TDEToolBar *bar, TDEActionCollection *ac )
-      : TDEToggleAction( i18n("Volume"), "volume", TQt::Key_1, 0, 0, ac, "volume" )
-      , m_anchor( 0 )
+      : TDEToggleAction( i18n("Volume"), "volume", TQt::Key_1, nullptr, nullptr, ac, "volume" )
+      , m_anchor( nullptr )
 {
    m_widget = new VolumeSlider( bar->topLevelWidget() );
 
