@@ -8,7 +8,7 @@
 
 class VolumeAction : public TDEToggleAction
 {
-   Q_OBJECT
+   TQ_OBJECT
 
    TQWidget *m_anchor;
    class VolumeSlider *m_widget;
@@ -17,9 +17,11 @@ class VolumeAction : public TDEToggleAction
 
    virtual int plug( TQWidget*, int );
 
+public slots:
+   void sliderMoved( int );
+
 private slots:
    void toggled( bool );
-   void sliderMoved( int );
    void sliderReleased() { setChecked( false ); toggled( false ); }
 
 public:
