@@ -25,19 +25,19 @@
 namespace Codeine {
 
 
-VideoWindow *VideoWindow::s_instance = 0;
+VideoWindow *VideoWindow::s_instance = nullptr;
 bool VideoWindow::s_logarithmicVolume = false;
 
 
 VideoWindow::VideoWindow( TQWidget *parent )
       : TQWidget( parent, "VideoWindow" )
-      , m_osd( 0 )
-      , m_stream( 0 )
-      , m_eventQueue( 0 )
-      , m_videoPort( 0 )
-      , m_audioPort( 0 )
-      , m_scope( 0 )
-      , m_xine( 0 )
+      , m_osd( nullptr )
+      , m_stream( nullptr )
+      , m_eventQueue( nullptr )
+      , m_videoPort( nullptr )
+      , m_audioPort( nullptr )
+      , m_scope( nullptr )
+      , m_xine( nullptr )
       , m_current_vpts( 0 )
 {
    DEBUG_BLOCK
@@ -136,7 +136,7 @@ VideoWindow::init()
    m_videoPort = xine_open_video_driver( m_xine, "auto", XINE_VISUAL_TYPE_X11, videoWindow()->x11Visual() );
 
    debug() << "xine_open_audio_driver()\n";
-   m_audioPort = xine_open_audio_driver( m_xine, "auto", NULL );
+   m_audioPort = xine_open_audio_driver( m_xine, "auto", nullptr );
 
    debug() << "xine_stream_new()\n";
    m_stream = xine_stream_new( m_xine, m_audioPort, m_videoPort );
@@ -161,7 +161,7 @@ VideoWindow::init()
    debug() << "scope_plugin_new()\n";
 #if XINE_MAJOR_VERSION > 1 || (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION > 2) || \
    (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION == 2 && XINE_SUB_VERSION >= 10)
-   m_scope = xine_post_init( m_xine, "codeine-scope", 1, &m_audioPort, NULL );
+   m_scope = xine_post_init( m_xine, "codeine-scope", 1, &m_audioPort, nullptr );
 #else
    m_scope = scope_plugin_new( m_xine, m_audioPort );
 
@@ -279,7 +279,7 @@ VideoWindow::load( const KURL &url )
 
       // ensure old buffers are deleted
       // FIXME leaves one erroneous buffer
-      timerEvent( 0 );
+      timerEvent( nullptr );
 
       if( m_scope ) {
          xine_post_out_t *source = xine_get_audio_source( m_stream );
@@ -579,13 +579,13 @@ VideoWindow::setStreamParameter( int value )
       parameter = XINE_PARAM_VO_CONTRAST;
    else if( sender == "brightness" )
       parameter = XINE_PARAM_VO_BRIGHTNESS;
-   else if( sender == "subtitle_channels_menu" )
+   else if( sender == "subtitle_channels_select" )
       parameter = XINE_PARAM_SPU_CHANNEL,
       value -= 2;
-   else if( sender == "audio_channels_menu" )
+   else if( sender == "audio_channels_select" )
       parameter = XINE_PARAM_AUDIO_CHANNEL_LOGICAL,
       value -= 2;
-   else if( sender == "aspect_ratio_menu" )
+   else if( sender == "aspect_ratio_select" )
       parameter = XINE_PARAM_VO_ASPECT_RATIO;
    else if( sender == "volume" )
    {
@@ -613,12 +613,12 @@ VideoWindow::scope()
       return scope;
 
    //prune the buffer list and update the m_current_vpts timestamp
-   timerEvent( 0 );
+   timerEvent( nullptr );
 
-   const int64_t pts_per_smpls  = 0; //scope_plugin_pts_per_smpls( m_scope );
+   // const int64_t pts_per_smpls  = 0; //scope_plugin_pts_per_smpls( m_scope );
    for( int channels = xine_get_stream_info( m_stream, XINE_STREAM_INFO_AUDIO_CHANNELS ), frame = 0; frame < SCOPE_SIZE; )
    {
-      MyNode *best_node = 0;
+      MyNode *best_node = nullptr;
 
       for( MyNode *node = myList->next; node != myList; node = node->next )
          if( node->vpts <= m_current_vpts && (!best_node || node->vpts > best_node->vpts) )
@@ -631,7 +631,7 @@ VideoWindow::scope()
       diff  = m_current_vpts;
       diff -= best_node->vpts;
       diff *= 1<<16;
-      diff /= pts_per_smpls;
+      // diff /= pts_per_smpls;
 
       const int16_t*
       data16  = best_node->mem;
@@ -709,19 +709,19 @@ VideoWindow::customEvent( TQCustomEvent *e )
       char s[128]; //apparently sufficient
 
       {
-         TQStringList languages( "subtitle_channels_menu" );
+         TQStringList languages;
          int channels = xine_get_stream_info( m_stream, XINE_STREAM_INFO_MAX_SPU_CHANNEL );
          for( int j = 0; j < channels; j++ )
             languages += xine_get_spu_lang( m_stream, j, s ) ? s : i18n("Channel %1").arg( j+1 );
-         emit channelsChanged( languages );
+         emit subtitleChannelsChanged(languages);
       }
 
       {
-         TQStringList languages( "audio_channels_menu" );
+         TQStringList languages;
          int channels = xine_get_stream_info( m_stream, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL );
          for( int j = 0; j < channels; j++ )
             languages += xine_get_audio_lang( m_stream, j, s ) ? s : i18n("Channel %1").arg( j+1 );
-         emit channelsChanged( languages );
+         emit audioChannelsChanged(languages);
       }
       break;
    }
@@ -880,7 +880,7 @@ VideoWindow::toggleDVDMenu()
 {
    xine_event_t e;
    e.type = XINE_EVENT_INPUT_MENU1;
-   e.data = NULL;
+   e.data = nullptr;
    e.data_length = 0;
 
    xine_event_send( m_stream, &e );
@@ -902,13 +902,37 @@ VideoWindow::fileFilter() const
 {
    char *supportedExtensions = xine_get_file_extensions( m_xine );
 
-   TQString filter( "*." );
-   filter.append( supportedExtensions );
-   filter.remove( "txt" );
-   filter.remove( "png" );
-   filter.replace( ' ', " *." );
+   TQString filter("*.");
+   filter.append(supportedExtensions);
 
-   std::free( supportedExtensions );
+   // Remove protocols
+   filter.remove(" dvb://");
+   filter.remove(" dvbc://");
+   filter.remove(" dvbs://");
+   filter.remove(" dvbt://");
+   filter.remove(" vcd:/");
+   filter.remove(" vdr:/");
+   filter.remove(" netvdr:/");
+   filter.remove(" dvd:/");
+   filter.remove(" pvr:/");
+   filter.remove(" slave://");
+   filter.remove(" cdda:/");
+
+   // Remove image files
+   filter.remove(" bmp");
+   filter.remove(" gif");
+   filter.remove(" jpg");
+   filter.remove(" jpeg");
+   filter.remove(" png");
+
+   // Remove misc. files
+   filter.remove(" txt");
+
+   // Remove spaces (prevent multiple *.)
+   filter.replace("  ", " ");
+   filter.replace(' ', " *.");
+
+   std::free(supportedExtensions);
 
    return filter;
 }
