@@ -83,7 +83,8 @@ namespace Codeine
       void stateChanged( Engine::State );
       void statusMessage( const TQString& );
       void titleChanged( const TQString& );
-      void channelsChanged( const TQStringList& );
+      void audioChannelsChanged( const TQStringList &);
+      void subtitleChannelsChanged( const TQStringList &);
 
    private:
       static void xineEventListener( void*, const xine_event_t* );
@@ -136,8 +137,6 @@ namespace Codeine
       void becomePreferredSize();
       TQImage captureFrame() const;
 
-      enum { ExposeEvent = 3000 };
-
    public slots:
       void resetZoom();
 
